---
hide:
  - navigation
  - footer
---

<!-- NOTE: This file is generated. Do not edit manually! -->

# Statistics on typeshed's stubs

Typeshed currently contains stubs for 139 packages
(including the stdlib stubs as a "single package"),
for a total of 185,472 non-empty lines of code.

<i>Note: these statistics were last updated at: <b>12:36 UTC on 2022-12-19</b>.</i>
<i>For up-to-date statistics, consider using the CLI tool instead.</i>
<hr>

## Info on typeshed's stubs for `D3DShot`

### Number of lines

590 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *skipped*

Stubtest is skipped in CI for this package.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `D3DShot`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 127
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 255
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 100
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `DateTimeRange`

### Number of lines

64 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `DateTimeRange`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 28
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 28
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 10
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `Deprecated`

### Number of lines

56 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `Deprecated`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 30
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 10
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 12
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `Flask-Cors`

### Number of lines

125 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `Flask-Cors`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 62
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 8
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 23
    - Unannotated returns: 0
    - Explicit `Any` returns: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 30
    - Explicit `Any` variables: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `Flask-Migrate`

### Number of lines

100 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *not strict*

All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `Flask-Migrate`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 74
    - Unannotated parameters: 4
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 20
    - Unannotated returns: 2
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 7
    - Explicit `Any` variables: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `Flask-SQLAlchemy`

### Number of lines

106 (excluding blank lines)

### Package status: *obsolete*

Upstream has added type hints; these typeshed stubs are now obsolete.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *not strict*

All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `Flask-SQLAlchemy`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 54
    - Unannotated parameters: 21
    - Explicit `Any` parameters: 20
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 5
- Returns:
    - Annotated returns: 24
    - Unannotated returns: 19
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 16
    - Explicit `Any` variables: 9
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `JACK-Client`

### Number of lines

281 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux and darwin.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `JACK-Client`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 107
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 5
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 151
    - Unannotated returns: 0
    - Explicit `Any` returns: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 26
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `Markdown`

### Number of lines

635 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *not strict*

All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `Markdown`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 112
    - Unannotated parameters: 145
    - Explicit `Any` parameters: 17
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 112
    - Unannotated returns: 65
    - Explicit `Any` returns: 6
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 214
    - Explicit `Any` variables: 83
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `Pillow`

### Number of lines

2,353 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *not strict*

All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `Pillow`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 629
    - Unannotated parameters: 619
    - Explicit `Any` parameters: 64
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 3
- Returns:
    - Annotated returns: 456
    - Unannotated returns: 347
    - Explicit `Any` returns: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 2
- Variables:
    - Annotated variables: 782
    - Explicit `Any` variables: 335
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `PyAutoGUI`

### Number of lines

219 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `PyAutoGUI`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 145
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 38
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 22
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `PyMySQL`

### Number of lines

1,039 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *not strict*

All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `PyMySQL`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 139
    - Unannotated parameters: 53
    - Explicit `Any` parameters: 38
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 98
    - Unannotated returns: 40
    - Explicit `Any` returns: 18
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 733
    - Explicit `Any` variables: 62
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `PyScreeze`

### Number of lines

177 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `PyScreeze`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 93
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 18
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 13
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `PyYAML`

### Number of lines

1,168 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *not strict*

All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `PyYAML`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 389
    - Unannotated parameters: 321
    - Explicit `Any` parameters: 52
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 158
    - Unannotated returns: 230
    - Explicit `Any` returns: 12
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 220
    - Explicit `Any` variables: 192
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `Pygments`

### Number of lines

677 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *not strict*

All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `Pygments`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 108
    - Unannotated parameters: 157
    - Explicit `Any` parameters: 24
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 96
    - Unannotated returns: 79
    - Explicit `Any` returns: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 2
- Variables:
    - Annotated variables: 313
    - Explicit `Any` variables: 193
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `SQLAlchemy`

### Extra description

The `sqlalchemy-stubs` package is an alternative to this package and also includes a mypy plugin for more precise types.

### Number of lines

14,545 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *not strict*

All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `SQLAlchemy`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 2,192
    - Unannotated parameters: 7,019
    - Explicit `Any` parameters: 1,168
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 37
- Returns:
    - Annotated returns: 2,158
    - Unannotated returns: 3,319
    - Explicit `Any` returns: 23
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 3,114
    - Explicit `Any` variables: 2,062
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 3

<hr>

## Info on typeshed's stubs for `Send2Trash`

### Number of lines

21 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `Send2Trash`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 4
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 3
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 4
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 1
- Variables:
    - Annotated variables: 2
    - Explicit `Any` variables: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `aiofiles`

### Number of lines

592 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux and win32.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `aiofiles`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 342
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 29
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 21
- Returns:
    - Annotated returns: 136
    - Unannotated returns: 0
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 7
- Variables:
    - Annotated variables: 0
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `annoy`

### Number of lines

45 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `annoy`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 40
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 20
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 1
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `appdirs`

### Number of lines

54 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `appdirs`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 33
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 15
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 8
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `aws-xray-sdk`

### Number of lines

705 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *not strict*

All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `aws-xray-sdk`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 127
    - Unannotated parameters: 166
    - Explicit `Any` parameters: 33
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 180
    - Unannotated returns: 94
    - Explicit `Any` returns: 3
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 141
    - Explicit `Any` variables: 46
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `babel`

### Number of lines

1,046 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *not strict*

All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `babel`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 395
    - Unannotated parameters: 225
    - Explicit `Any` parameters: 52
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 249
    - Unannotated returns: 121
    - Explicit `Any` returns: 5
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 245
    - Explicit `Any` variables: 149
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `backports.ssl_match_hostname`

### Number of lines

6 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `backports.ssl_match_hostname`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 3
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 2
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 1
- Variables:
    - Annotated variables: 0
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `beautifulsoup4`

### Number of lines

784 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *not strict*

All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `beautifulsoup4`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 240
    - Unannotated parameters: 137
    - Explicit `Any` parameters: 32
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 193
    - Unannotated returns: 49
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 177
    - Explicit `Any` variables: 71
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `bleach`

### Number of lines

160 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *not strict*

All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `bleach`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 58
    - Unannotated parameters: 17
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 25
    - Unannotated returns: 9
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 6
- Variables:
    - Annotated variables: 39
    - Explicit `Any` variables: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `boto`

### Number of lines

1,803 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *not strict*

All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `boto`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 837
    - Unannotated parameters: 685
    - Explicit `Any` parameters: 366
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 168
    - Unannotated returns: 442
    - Explicit `Any` returns: 31
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 2
- Variables:
    - Annotated variables: 363
    - Explicit `Any` variables: 267
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `braintree`

### Number of lines

2,833 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *not strict*

All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `braintree`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 80
    - Unannotated parameters: 394
    - Explicit `Any` parameters: 74
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 1
- Returns:
    - Annotated returns: 113
    - Unannotated returns: 304
    - Explicit `Any` returns: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 1,301
    - Explicit `Any` variables: 432
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `cachetools`

### Number of lines

115 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `cachetools`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 86
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 48
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 1
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `caldav`

### Number of lines

490 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *not strict*

All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `caldav`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 204
    - Unannotated parameters: 29
    - Explicit `Any` parameters: 25
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 3
- Returns:
    - Annotated returns: 111
    - Unannotated returns: 7
    - Explicit `Any` returns: 5
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 90
    - Explicit `Any` variables: 6
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `cffi`

### Number of lines

820 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux and win32.

### Pyright settings in CI: *not strict*

All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `cffi`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 295
    - Unannotated parameters: 251
    - Explicit `Any` parameters: 33
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 20
- Returns:
    - Annotated returns: 191
    - Unannotated returns: 132
    - Explicit `Any` returns: 8
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 2
- Variables:
    - Annotated variables: 252
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 115

<hr>

## Info on typeshed's stubs for `chardet`

### Number of lines

122 (excluding blank lines)

### Package status: *obsolete*

Upstream has added type hints; these typeshed stubs are now obsolete.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `chardet`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 5
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 7
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 86
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `chevron`

### Number of lines

39 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `chevron`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 29
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 9
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 3
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `click-spinner`

### Number of lines

31 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `click-spinner`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 12
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 11
    - Unannotated returns: 0
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 9
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `colorama`

### Number of lines

197 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on win32 and linux.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `colorama`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 89
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 3
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 60
    - Unannotated returns: 0
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 85
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `commonmark`

### Number of lines

368 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *not strict*

All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `commonmark`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 63
    - Unannotated parameters: 158
    - Explicit `Any` parameters: 55
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 84
    - Unannotated returns: 76
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 133
    - Explicit `Any` variables: 86
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `console-menu`

### Number of lines

686 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `console-menu`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 210
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 7
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 278
    - Unannotated returns: 0
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 57
    - Explicit `Any` variables: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `contextvars`

### Number of lines

41 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `contextvars`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 12
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 17
    - Unannotated returns: 0
    - Explicit `Any` returns: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 1
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `croniter`

### Number of lines

90 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `croniter`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 35
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 16
    - Unannotated returns: 0
    - Explicit `Any` returns: 9
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 13
    - Explicit `Any` variables: 3
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `cryptography`

### Number of lines

1,742 (excluding blank lines)

### Package status: *obsolete*

Upstream has added type hints; these typeshed stubs are now obsolete.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *skipped*

Stubtest is skipped in CI for this package.

### Pyright settings in CI: *entirely excluded*

All files are excluded from the pyright check in CI.

### Statistics on the annotations in typeshed's stubs for `cryptography`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 615
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 3
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 552
    - Unannotated returns: 14
    - Explicit `Any` returns: 18
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 5
- Variables:
    - Annotated variables: 279
    - Explicit `Any` variables: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `dateparser`

### Number of lines

460 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *not strict*

All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `dateparser`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 126
    - Unannotated parameters: 127
    - Explicit `Any` parameters: 25
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 75
    - Unannotated returns: 67
    - Explicit `Any` returns: 6
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 1
- Variables:
    - Annotated variables: 135
    - Explicit `Any` variables: 76
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `decorator`

### Number of lines

64 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `decorator`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 36
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 19
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 13
    - Unannotated returns: 0
    - Explicit `Any` returns: 6
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 14
    - Explicit `Any` variables: 3
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `dj-database-url`

### Number of lines

37 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `dj-database-url`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 13
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 2
- Returns:
    - Annotated returns: 2
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 15
    - Explicit `Any` variables: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `dockerfile-parse`

### Number of lines

109 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `dockerfile-parse`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 46
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 24
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 38
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `docopt`

### Number of lines

9 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `docopt`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 6
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 2
    - Unannotated returns: 0
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 1
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `docutils`

### Number of lines

503 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *not strict*

All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `docutils`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 213
    - Unannotated parameters: 60
    - Explicit `Any` parameters: 36
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 148
    - Unannotated returns: 10
    - Explicit `Any` returns: 6
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 45
- Variables:
    - Annotated variables: 80
    - Explicit `Any` variables: 11
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `editdistance`

### Number of lines

3 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `editdistance`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 4
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 2
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 0
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `emoji`

### Number of lines

66 (excluding blank lines)

### Package status: *obsolete*

Upstream has added type hints; these typeshed stubs are now obsolete.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `emoji`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 21
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 10
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 12
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 1

<hr>

## Info on typeshed's stubs for `entrypoints`

### Number of lines

45 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `entrypoints`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 23
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 12
    - Unannotated returns: 0
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 12
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `first`

### Number of lines

14 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `first`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 8
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 4
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 2
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `flake8-2020`

### Number of lines

22 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `flake8-2020`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 1
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 2
    - Unannotated returns: 0
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 12
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `flake8-bugbear`

### Number of lines

27 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `flake8-bugbear`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 8
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 5
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 2
- Variables:
    - Annotated variables: 8
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `flake8-builtins`

### Number of lines

10 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `flake8-builtins`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 3
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 3
    - Unannotated returns: 0
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 1
- Variables:
    - Annotated variables: 2
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `flake8-docstrings`

### Number of lines

19 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `flake8-docstrings`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 6
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 5
    - Unannotated returns: 0
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 1
- Variables:
    - Annotated variables: 6
    - Explicit `Any` variables: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `flake8-plugin-utils`

### Number of lines

61 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `flake8-plugin-utils`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 30
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 6
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 17
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 9
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `flake8-rst-docstrings`

### Number of lines

31 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `flake8-rst-docstrings`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 10
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 5
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 12
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `flake8-simplify`

### Number of lines

8 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `flake8-simplify`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 1
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 2
    - Unannotated returns: 0
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 2
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `flake8-typing-imports`

### Number of lines

15 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `flake8-typing-imports`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 4
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 5
    - Unannotated returns: 0
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 1
- Variables:
    - Annotated variables: 2
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `fpdf2`

### Number of lines

2,001 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *not strict*

All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `fpdf2`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 578
    - Unannotated parameters: 522
    - Explicit `Any` parameters: 11
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 58
- Returns:
    - Annotated returns: 369
    - Unannotated returns: 193
    - Explicit `Any` returns: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 4
- Variables:
    - Annotated variables: 625
    - Explicit `Any` variables: 14
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 159

<hr>

## Info on typeshed's stubs for `gdb`

### Extra description

Type hints for GDB's [Python API](https://sourceware.org/gdb/onlinedocs/gdb/Python-API.html). Note that this API is available only when running Python scripts under GDB: is is not possible to install the `gdb` package separately, for instance using `pip`.

### Number of lines

718 (excluding blank lines)

### Package status: *not on pypi*

The upstream for this package doesn't exist on PyPI, so whether or not these stubs are up to date or not is unknown.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *skipped*

Stubtest is skipped in CI for this package.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `gdb`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 227
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 247
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 290
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `google-cloud-ndb`

### Number of lines

1,408 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *not strict*

All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `google-cloud-ndb`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 479
    - Unannotated parameters: 368
    - Explicit `Any` parameters: 127
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 3
- Returns:
    - Annotated returns: 234
    - Unannotated returns: 203
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 190
    - Explicit `Any` variables: 132
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 2

<hr>

## Info on typeshed's stubs for `hdbcli`

### Number of lines

129 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `hdbcli`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 77
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 12
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 6
- Returns:
    - Annotated returns: 62
    - Unannotated returns: 0
    - Explicit `Any` returns: 7
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 4
- Variables:
    - Annotated variables: 21
    - Explicit `Any` variables: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 2

<hr>

## Info on typeshed's stubs for `html5lib`

### Number of lines

663 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *not strict*

All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `html5lib`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 67
    - Unannotated parameters: 207
    - Explicit `Any` parameters: 27
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 100
    - Unannotated returns: 208
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 220
    - Explicit `Any` variables: 180
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `httplib2`

### Number of lines

250 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *not strict*

All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `httplib2`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 46
    - Unannotated parameters: 122
    - Explicit `Any` parameters: 37
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 39
    - Unannotated returns: 25
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 86
    - Explicit `Any` variables: 57
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `humanfriendly`

### Number of lines

333 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *not strict*

All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `humanfriendly`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 79
    - Unannotated parameters: 181
    - Explicit `Any` parameters: 22
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 82
    - Unannotated returns: 95
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 75
    - Explicit `Any` variables: 54
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `invoke`

### Number of lines

745 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *not strict*

All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `invoke`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 245
    - Unannotated parameters: 171
    - Explicit `Any` parameters: 28
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 177
    - Unannotated returns: 73
    - Explicit `Any` returns: 8
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 129
    - Explicit `Any` variables: 70
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `jmespath`

### Number of lines

172 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *not strict*

All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `jmespath`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 67
    - Unannotated parameters: 66
    - Explicit `Any` parameters: 26
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 49
    - Unannotated returns: 25
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 1
- Variables:
    - Annotated variables: 48
    - Explicit `Any` variables: 26
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `jsonschema`

### Number of lines

385 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *not strict*

All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `jsonschema`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 108
    - Unannotated parameters: 295
    - Explicit `Any` parameters: 22
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 145
    - Unannotated returns: 31
    - Explicit `Any` returns: 9
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 1
- Variables:
    - Annotated variables: 54
    - Explicit `Any` variables: 23
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `keyboard`

### Number of lines

241 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `keyboard`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 130
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 76
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 38
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `ldap3`

### Number of lines

2,586 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *not strict*

All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `ldap3`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 533
    - Unannotated parameters: 675
    - Explicit `Any` parameters: 294
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 216
    - Unannotated returns: 423
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 931
    - Explicit `Any` variables: 439
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `mock`

### Number of lines

311 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `mock`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 185
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 124
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 82
    - Unannotated returns: 0
    - Explicit `Any` returns: 15
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 52
    - Explicit `Any` variables: 34
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `mypy-extensions`

### Number of lines

64 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `mypy-extensions`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 28
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 25
    - Unannotated returns: 0
    - Explicit `Any` returns: 7
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 1
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `mysqlclient`

### Number of lines

1,213 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *not strict*

All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `mysqlclient`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 28
    - Unannotated parameters: 128
    - Explicit `Any` parameters: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 83
    - Unannotated returns: 30
    - Explicit `Any` returns: 51
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 972
    - Explicit `Any` variables: 31
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `oauthlib`

### Number of lines

1,296 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *not strict*

All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `oauthlib`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 274
    - Unannotated parameters: 541
    - Explicit `Any` parameters: 185
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 139
    - Unannotated returns: 211
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 318
    - Explicit `Any` variables: 207
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `openpyxl`

### Number of lines

8,979 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *not strict*

All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `openpyxl`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 2,597
    - Unannotated parameters: 660
    - Explicit `Any` parameters: 2,218
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 744
    - Unannotated returns: 423
    - Explicit `Any` returns: 19
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 4,197
    - Explicit `Any` variables: 3,566
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `opentracing`

### Number of lines

328 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `opentracing`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 105
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 22
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 113
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 56
    - Explicit `Any` variables: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `paho-mqtt`

### Number of lines

502 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `paho-mqtt`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 217
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 5
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 147
    - Unannotated returns: 0
    - Explicit `Any` returns: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 145
    - Explicit `Any` variables: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `paramiko`

### Number of lines

1,749 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux and win32.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `paramiko`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 748
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 25
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 630
    - Unannotated returns: 0
    - Explicit `Any` returns: 9
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 537
    - Explicit `Any` variables: 21
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `parsimonious`

### Number of lines

180 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `parsimonious`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 114
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 23
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 60
    - Unannotated returns: 0
    - Explicit `Any` returns: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 34
    - Explicit `Any` variables: 5
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `passlib`

### Number of lines

1,740 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *not strict*

All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `passlib`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 382
    - Unannotated parameters: 466
    - Explicit `Any` parameters: 174
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 155
    - Unannotated returns: 329
    - Explicit `Any` returns: 10
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 576
    - Explicit `Any` variables: 105
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `passpy`

### Number of lines

47 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `passpy`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 43
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 20
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 1
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `peewee`

### Number of lines

1,608 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *not strict*

All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `peewee`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 370
    - Unannotated parameters: 704
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 244
- Returns:
    - Annotated returns: 298
    - Unannotated returns: 448
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 5
- Variables:
    - Annotated variables: 437
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 368

<hr>

## Info on typeshed's stubs for `pep8-naming`

### Number of lines

27 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `pep8-naming`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 10
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 8
    - Unannotated returns: 0
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 2
- Variables:
    - Annotated variables: 11
    - Explicit `Any` variables: 3
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `pika`

### Extra description

The `types-pika` package contains alternate, more complete type stubs, that are maintained outside of typeshed.

### Number of lines

2,163 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *not strict*

All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `pika`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 591
    - Unannotated parameters: 410
    - Explicit `Any` parameters: 3
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 165
- Returns:
    - Annotated returns: 368
    - Unannotated returns: 392
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 3
- Variables:
    - Annotated variables: 470
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 262

<hr>

## Info on typeshed's stubs for `playsound`

### Number of lines

3 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `playsound`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 2
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 1
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 0
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `polib`

### Number of lines

144 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `polib`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 61
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 18
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 75
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 45
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `prettytable`

### Number of lines

294 (excluding blank lines)

### Package status: *obsolete*

Upstream has added type hints; these typeshed stubs are now obsolete.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *not strict*

All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `prettytable`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 18
    - Unannotated parameters: 77
    - Explicit `Any` parameters: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 1
- Returns:
    - Annotated returns: 70
    - Unannotated returns: 56
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 1
- Variables:
    - Annotated variables: 34
    - Explicit `Any` variables: 6
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `protobuf`

### Extra description

Generated with aid from mypy-protobuf v3.4.0

### Number of lines

4,280 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *not strict*

All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `protobuf`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 726
    - Unannotated parameters: 248
    - Explicit `Any` parameters: 27
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 494
    - Unannotated returns: 79
    - Explicit `Any` returns: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 738
    - Explicit `Any` variables: 126
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `psutil`

### Number of lines

1,506 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on win32, linux and darwin.

### Pyright settings in CI: *not strict*

All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `psutil`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 117
    - Unannotated parameters: 310
    - Explicit `Any` parameters: 26
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 2
- Returns:
    - Annotated returns: 185
    - Unannotated returns: 358
    - Explicit `Any` returns: 47
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 585
    - Explicit `Any` variables: 206
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 71

<hr>

## Info on typeshed's stubs for `psycopg2`

### Number of lines

1,552 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *not strict*

All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `psycopg2`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 171
    - Unannotated parameters: 328
    - Explicit `Any` parameters: 56
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 189
    - Unannotated returns: 169
    - Explicit `Any` returns: 7
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 532
    - Explicit `Any` variables: 168
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `pyOpenSSL`

### Number of lines

373 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `pyOpenSSL`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 163
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 3
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 3
- Returns:
    - Annotated returns: 198
    - Unannotated returns: 0
    - Explicit `Any` returns: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 2
- Variables:
    - Annotated variables: 119
    - Explicit `Any` variables: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `pyRFC3339`

### Number of lines

17 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `pyRFC3339`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 15
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 9
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 0
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `pyaudio`

### Number of lines

177 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux and darwin.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `pyaudio`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 53
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 38
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 84
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `pycocotools`

### Number of lines

172 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `pycocotools`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 51
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 35
    - Unannotated returns: 0
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 64
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 1

<hr>

## Info on typeshed's stubs for `pycurl`

### Number of lines

674 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `pycurl`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 22
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 7
- Returns:
    - Annotated returns: 32
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 10
- Variables:
    - Annotated variables: 629
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `pyfarmhash`

### Number of lines

9 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `pyfarmhash`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 13
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 9
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 0
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `pyflakes`

### Number of lines

428 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *not strict*

All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `pyflakes`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 267
    - Unannotated parameters: 69
    - Explicit `Any` parameters: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 210
    - Unannotated returns: 2
    - Explicit `Any` returns: 3
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 76
    - Explicit `Any` variables: 33
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `pyinstaller`

### Number of lines

418 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `pyinstaller`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 186
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 9
- Returns:
    - Annotated returns: 114
    - Unannotated returns: 0
    - Explicit `Any` returns: 3
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 96
    - Explicit `Any` variables: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `pynput`

### Number of lines

325 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux, darwin and win32.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `pynput`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 81
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 11
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 71
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 155
    - Explicit `Any` variables: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `pysftp`

### Number of lines

162 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `pysftp`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 109
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 70
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 6
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `pytest-lazy-fixture`

### Number of lines

12 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `pytest-lazy-fixture`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 5
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 5
    - Unannotated returns: 0
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 1
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `python-crontab`

### Number of lines

270 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *not strict*

All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `python-crontab`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 90
    - Unannotated parameters: 43
    - Explicit `Any` parameters: 10
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 18
- Returns:
    - Annotated returns: 80
    - Unannotated returns: 58
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 7
- Variables:
    - Annotated variables: 67
    - Explicit `Any` variables: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 32

<hr>

## Info on typeshed's stubs for `python-dateutil`

### Number of lines

441 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *not strict*

All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `python-dateutil`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 171
    - Unannotated parameters: 66
    - Explicit `Any` parameters: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 3
- Returns:
    - Annotated returns: 106
    - Unannotated returns: 48
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 90
    - Explicit `Any` variables: 13
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 1

<hr>

## Info on typeshed's stubs for `python-gflags`

### Number of lines

251 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `python-gflags`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 186
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 39
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 98
    - Unannotated returns: 0
    - Explicit `Any` returns: 9
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 19
    - Explicit `Any` variables: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `python-jose`

### Number of lines

359 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *not strict*

All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `python-jose`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 86
    - Unannotated parameters: 39
    - Explicit `Any` parameters: 18
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 60
    - Unannotated returns: 30
    - Explicit `Any` returns: 12
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 117
    - Explicit `Any` variables: 33
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `python-nmap`

### Number of lines

116 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `python-nmap`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 44
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 44
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 31
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `python-slugify`

### Number of lines

45 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `python-slugify`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 19
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 3
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 12
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `python-xlib`

### Number of lines

5,396 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `python-xlib`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 1,335
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 15
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 583
    - Unannotated returns: 0
    - Explicit `Any` returns: 8
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 3,527
    - Explicit `Any` variables: 5
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `pytz`

### Number of lines

127 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `pytz`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 69
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 2
- Returns:
    - Annotated returns: 51
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 1
- Variables:
    - Annotated variables: 27
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 1

<hr>

## Info on typeshed's stubs for `pyvmomi`

### Number of lines

177 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `pyvmomi`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 50
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 3
- Returns:
    - Annotated returns: 35
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 16
- Variables:
    - Annotated variables: 57
    - Explicit `Any` variables: 7
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `pywin32`

### Number of lines

34,530 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on win32 only.

### Pyright settings in CI: *not strict*

All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `pywin32`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 3,635
    - Unannotated parameters: 3,729
    - Explicit `Any` parameters: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 426
- Returns:
    - Annotated returns: 3,825
    - Unannotated returns: 2,043
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 292
- Variables:
    - Annotated variables: 25,012
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 2,832

<hr>

## Info on typeshed's stubs for `redis`

### Number of lines

5,336 (excluding blank lines)

### Package status: *out of date*

These stubs are out of date. In CI, stubtest tests these stubs against an older version of this package than the latest that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *not strict*

All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `redis`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 3,462
    - Unannotated parameters: 1,300
    - Explicit `Any` parameters: 318
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 88
- Returns:
    - Annotated returns: 1,265
    - Unannotated returns: 657
    - Explicit `Any` returns: 317
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 2
- Variables:
    - Annotated variables: 595
    - Explicit `Any` variables: 235
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 12

<hr>

## Info on typeshed's stubs for `regex`

### Number of lines

749 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `regex`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 429
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 25
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 114
    - Unannotated returns: 0
    - Explicit `Any` returns: 16
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 72
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `requests`

### Number of lines

967 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *not strict*

All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `requests`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 349
    - Unannotated parameters: 157
    - Explicit `Any` parameters: 25
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 3
- Returns:
    - Annotated returns: 111
    - Unannotated returns: 86
    - Explicit `Any` returns: 5
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 114
    - Explicit `Any` variables: 43
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `retry`

### Number of lines

27 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `retry`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 17
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 2
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 0
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `setuptools`

### Number of lines

2,433 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *not strict*

All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `setuptools`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 821
    - Unannotated parameters: 393
    - Explicit `Any` parameters: 73
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 3
- Returns:
    - Annotated returns: 658
    - Unannotated returns: 262
    - Explicit `Any` returns: 6
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 627
    - Explicit `Any` variables: 401
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 9

<hr>

## Info on typeshed's stubs for `simplejson`

### Number of lines

51 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `simplejson`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 36
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 14
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 16
    - Unannotated returns: 0
    - Explicit `Any` returns: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 17
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `singledispatch`

### Number of lines

27 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `singledispatch`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 16
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 7
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 12
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 3
    - Explicit `Any` variables: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `six`

### Number of lines

335 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `six`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 71
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 9
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 40
    - Unannotated returns: 0
    - Explicit `Any` returns: 6
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 13
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `slumber`

### Number of lines

74 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `slumber`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 43
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 11
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 25
    - Unannotated returns: 0
    - Explicit `Any` returns: 5
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 9
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `stdlib`

### Number of lines

50,953 (excluding blank lines)

### Package status: *stdlib*

These are the stdlib stubs. Typeshed's stdlib stubs are generally fairly up to date, and tested against all currently supported Python versions in CI.

### Upload status: *not currently uploaded*

These stubs are not currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux, darwin and win32.

### Pyright settings in CI: *strict on some files*

Some files are tested with the stricter pyright settings in CI; some are excluded.

### Statistics on the annotations in typeshed's stubs for `stdlib`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 24,457
    - Unannotated parameters: 713
    - Explicit `Any` parameters: 2,044
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 85
- Returns:
    - Annotated returns: 13,297
    - Unannotated returns: 405
    - Explicit `Any` returns: 817
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 18
- Variables:
    - Annotated variables: 8,070
    - Explicit `Any` variables: 556
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 101

<hr>

## Info on typeshed's stubs for `stdlib-list`

### Number of lines

16 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `stdlib-list`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 4
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 4
    - Unannotated returns: 0
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 4
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `stripe`

### Number of lines

1,414 (excluding blank lines)

### Package status: *out of date*

These stubs are out of date. In CI, stubtest tests these stubs against an older version of this package than the latest that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *not strict*

All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `stripe`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 264
    - Unannotated parameters: 388
    - Explicit `Any` parameters: 161
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 108
    - Unannotated returns: 168
    - Explicit `Any` returns: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 155
    - Explicit `Any` variables: 42
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `tabulate`

### Number of lines

50 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `tabulate`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 15
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 2
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 25
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `termcolor`

### Number of lines

12 (excluding blank lines)

### Package status: *obsolete*

Upstream has added type hints; these typeshed stubs are now obsolete.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `termcolor`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 9
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 2
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 6
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `toml`

### Number of lines

136 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `toml`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 71
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 20
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 41
    - Unannotated returns: 0
    - Explicit `Any` returns: 5
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 14
    - Explicit `Any` variables: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `toposort`

### Number of lines

13 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `toposort`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 4
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 4
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 1
    - Explicit `Any` variables: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `tqdm`

### Number of lines

1,333 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *not strict*

All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `tqdm`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 788
    - Unannotated parameters: 129
    - Explicit `Any` parameters: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 18
- Returns:
    - Annotated returns: 139
    - Unannotated returns: 24
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 8
- Variables:
    - Annotated variables: 95
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 70

<hr>

## Info on typeshed's stubs for `tree-sitter`

### Number of lines

124 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `tree-sitter`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 25
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 52
    - Unannotated returns: 0
    - Explicit `Any` returns: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 4
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `tree-sitter-languages`

### Number of lines

9 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `tree-sitter-languages`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 2
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 2
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 5
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `ttkthemes`

### Number of lines

76 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *not strict*

All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `ttkthemes`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 30
    - Unannotated parameters: 14
    - Explicit `Any` parameters: 3
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 13
    - Unannotated returns: 10
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 5
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `typed-ast`

### Number of lines

578 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `typed-ast`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 46
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 29
    - Unannotated returns: 0
    - Explicit `Any` returns: 6
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 309
    - Explicit `Any` variables: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `tzlocal`

### Number of lines

19 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `tzlocal`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 2
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 6
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 3
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `ujson`

### Number of lines

34 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `ujson`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 28
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 3
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 6
    - Unannotated returns: 0
    - Explicit `Any` returns: 3
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 1
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `urllib3`

### Number of lines

699 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *not strict*

All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `urllib3`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 158
    - Unannotated parameters: 160
    - Explicit `Any` parameters: 3
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 95
    - Unannotated returns: 61
    - Explicit `Any` returns: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 155
    - Explicit `Any` variables: 54
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `vobject`

### Number of lines

519 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *not strict*

All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `vobject`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 101
    - Unannotated parameters: 179
    - Explicit `Any` parameters: 21
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 73
    - Unannotated returns: 103
    - Explicit `Any` returns: 3
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 184
    - Explicit `Any` variables: 93
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `waitress`

### Number of lines

628 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux and win32.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `waitress`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 210
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 44
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 209
    - Unannotated returns: 0
    - Explicit `Any` returns: 8
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 246
    - Explicit `Any` variables: 20
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `whatthepatch`

### Number of lines

96 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `whatthepatch`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 31
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 24
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 50
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `xmltodict`

### Number of lines

35 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `xmltodict`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 20
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 7
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 3
    - Unannotated returns: 0
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 1
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Info on typeshed's stubs for `xxhash`

### Number of lines

43 (excluding blank lines)

### Package status: *obsolete*

Upstream has added type hints; these typeshed stubs are now obsolete.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `xxhash`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 26
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 17
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 6
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 1

<hr>

## Info on typeshed's stubs for `zxcvbn`

### Number of lines

162 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in CI.

### Stubtest platforms in CI

In CI, stubtest is run on linux only.

### Pyright settings in CI: *strict*

All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `zxcvbn`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 63
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 39
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 76
    - Explicit `Any` variables: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
